@@ -8,21 +8,13 @@
 #include "grantleeki18nlocalizer_p.h"
 #include "kcalutils_debug.h"
 
-#include <QLocale>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <grantlee/safestring.h>
-#else
 #include <KTextTemplate/SafeString>
-#endif
+#include <QLocale>
 
 #include <KLocalizedString>
 
 GrantleeKi18nLocalizer::GrantleeKi18nLocalizer()
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    : Grantlee::QtLocalizer()
-#else
     : KTextTemplate::QtLocalizer()
-#endif
 {
 }
 
@@ -34,41 +26,6 @@ QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr, c
 {
     KLocalizedString str = kstr;
     for (auto iter = arguments.cbegin(), end = arguments.cend(); iter != end; ++iter) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        switch (iter->type()) {
-        case QVariant::String:
-            str = str.subs(iter->toString());
-            break;
-        case QVariant::Int:
-            str = str.subs(iter->toInt());
-            break;
-        case QVariant::UInt:
-            str = str.subs(iter->toUInt());
-            break;
-        case QVariant::LongLong:
-            str = str.subs(iter->toLongLong());
-            break;
-        case QVariant::ULongLong:
-            str = str.subs(iter->toULongLong());
-            break;
-        case QVariant::Char:
-            str = str.subs(iter->toChar());
-            break;
-        case QVariant::Double:
-            str = str.subs(iter->toDouble());
-            break;
-        case QVariant::UserType:
-            if (iter->canConvert<Grantlee::SafeString>()) {
-                str = str.subs(iter->value<Grantlee::SafeString>().get());
-                break;
-            }
-            // fall-through
-            Q_FALLTHROUGH();
-        default:
-            qCWarning(KCALUTILS_LOG) << "Unknown type" << iter->typeName() << "(" << iter->type() << ")";
-            break;
-        }
-#else
         switch (iter->userType()) {
         case QMetaType::QString:
             str = str.subs(iter->toString());
@@ -101,7 +58,6 @@ QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr, c
                 break;
             }
         }
-#endif
     }
 
     // Return localized in the currently active locale
